@@ -8,8 +8,7 @@
 #include <htparse.h>
 
 #ifndef EVHTP_DISABLE_REGEX
-#include <sys/types.h>
-#include <regex.h>
+#include <onigposix.h>
 #endif
 
 #include <sys/queue.h>
